Class: RiotAPI::Strategies::Summoner
- Defined in:
- lib/riot_api/strategies/summoner.rb
Instance Method Summary collapse
-
#by_ids(ids) ⇒ Object
Get summoner objects mapped by summoner ID for a given list of summoner IDs.
-
#by_names(names) ⇒ Object
Get summoner objects mapped by standardized summoner name for a given list of summoner names.
-
#initialize(params = {}) ⇒ Summoner
constructor
A new instance of Summoner.
-
#masteries_by_ids(ids) ⇒ Object
Get mastery pages mapped by summoner ID for a given list of summoner IDs.
-
#names_by_ids(ids) ⇒ Object
Get summoner names mapped by summoner ID for a given list of summoner IDs.
-
#runes_by_ids(ids) ⇒ Object
Get rune pages mapped by summoner ID for a given list of summoner IDs.
Methods inherited from Default
Constructor Details
#initialize(params = {}) ⇒ Summoner
Returns a new instance of Summoner.
8 9 10 11 12 13 14 |
# File 'lib/riot_api/strategies/summoner.rb', line 8 def initialize(params={}) = { version: "v1.4", type: "summoner" }.merge(params) super end |
Instance Method Details
#by_ids(ids) ⇒ Object
Get summoner objects mapped by summoner ID for a given list of summoner IDs
24 25 26 |
# File 'lib/riot_api/strategies/summoner.rb', line 24 def by_ids(ids) request_url + "/" + ids end |
#by_names(names) ⇒ Object
Get summoner objects mapped by standardized summoner name for a given list of summoner names
18 19 20 |
# File 'lib/riot_api/strategies/summoner.rb', line 18 def by_names(names) request_url + "/by-name/" + names end |
#masteries_by_ids(ids) ⇒ Object
Get mastery pages mapped by summoner ID for a given list of summoner IDs
30 31 32 |
# File 'lib/riot_api/strategies/summoner.rb', line 30 def masteries_by_ids(ids) request_url + "/" + ids + "/masteries" end |
#names_by_ids(ids) ⇒ Object
Get summoner names mapped by summoner ID for a given list of summoner IDs
36 37 38 |
# File 'lib/riot_api/strategies/summoner.rb', line 36 def names_by_ids(ids) request_url + "/" + ids + "/name" end |
#runes_by_ids(ids) ⇒ Object
Get rune pages mapped by summoner ID for a given list of summoner IDs
42 43 44 |
# File 'lib/riot_api/strategies/summoner.rb', line 42 def runes_by_ids(ids) request_url + "/" + ids + "/runes" end |